==> redquicklib-1.289.0.tgz: package/lib/geocodeservice.js <==
import _Qs from 'qs';
var Qs = _Qs && _Qs.default ? _Qs.default : _Qs;
import createService from './service';
import { parameters } from './endPoints';
const endpoints = {
}
var formatjson = '?format=json';
var googleservice = createService('https://maps.googleapis.com/maps', null, true);
var queryKey = null;
var directionsKey = null;
export const queryOps = { result_type: 'street_address' }
export default {
    setKey: (key) => {
        queryKey = key;
    },
    setDirectionsKey: key => {
        directionsKey = key;
    },
    getGeoCodes: async (latitude, longitude, query) => {
        query = query || queryOps;
        var qstring = Qs.stringify(Object.assign({}, {
            latlng: latitude + ',' + longitude,
            key: queryKey
        }, query
        ));
        return googleservice.get(parameters('api/geocode/json?') + qstring);
    },
    getDirections: async (origin, destination, query) => {
        //https://maps.googleapis.com/maps/api/directions/json?origin=Toronto&destination=Montreal&key=YOUR_API_KEY
        query = query || {};
        if (!origin || !destination) {
            return Promise.reject('no origin provided');
        }
        var qstring = Qs.stringify(Object.assign({}, {
            origin: origin.latitude + ',' + origin.longitude,
            destination: destination.latitude + ',' + destination.longitude,
            key: directionsKey || queryKey
        },
            query
        ));
        return googleservice.get(parameters('api/directions/json?') + qstring);
    }
};

==> redquicklib-1.500.0.tgz: package/lib/geocodeservice.js <==
import _Qs from 'qs';
var Qs = _Qs && _Qs.default ? _Qs.default : _Qs;
import * as RED from './service';
import { parameters } from './endPoints';
const endpoints = {
}
var formatjson = '?format=json';
var googleservice = RED.createRedService('https://maps.googleapis.com/maps', null, true);
var queryKey = null;
var directionsKey = null;
export const queryOps = { result_type: 'street_address' }
export default {
    setKey: (key) => {
        queryKey = key;
    },
    setDirectionsKey: key => {
        directionsKey = key;
    },
    getGeoCodes: async (latitude, longitude, query) => {
        query = query || queryOps;
        var qstring = Qs.stringify(Object.assign({}, {
            latlng: latitude + ',' + longitude,
            key: queryKey
        }, query
        ));
        return googleservice.get(parameters('api/geocode/json?') + qstring);
    },
    getDirections: async (origin, destination, query) => {
        //https://maps.googleapis.com/maps/api/directions/json?origin=Toronto&destination=Montreal&key=YOUR_API_KEY
        query = query || {};
        if (!origin || !destination) {
            return Promise.reject('no origin provided');
        }
        var qstring = Qs.stringify(Object.assign({}, {
            origin: origin.latitude + ',' + origin.longitude,
            destination: destination.latitude + ',' + destination.longitude,
            key: directionsKey || queryKey
        },
            query
        ));
        return googleservice.get(parameters('api/directions/json?') + qstring);
    }
};
